Core Object — COGNAC documentation

# Core Object

## BaseEnv

class cognac.core.BaseEnv.BaseNetworkedEnv

  Bases: `ABC`

  Note

  This is a core object for Environment instance. It is a work in progress to build a common basis for all networked based environments.

## BaseReward

class cognac.core.BaseReward.BaseReward

  Bases: `ABC`

  Note

  This is a core object for Reward instance. It is a work in progress to build a common basis for all networked based environments.

  reset(init_state)